@@ -207,7 +207,7 @@ proc suppr_job { w } {
                   set ilast $tabj($nsrv,nbj)
                }
                #
-               set cmd "/bin/sh -c \""
+               set cmd "$astk::cmd(shell_cmd) \""
                # liste des jobs confirms pour suppression
                set ljconf [list]
                for {set nf $ideb} {$nf <= $ilast} {incr nf} {
@@ -414,6 +414,7 @@ proc editJobSel {w type} {
 # type      output/error
 #
    global env
+   set action $type
 
    if { [$w curselection] == "" } {
       set asjob::status "<ALARME> Slectionner tout d'abord un job !"
@@ -436,13 +437,27 @@ proc editJobSel {w type} {
             if { $is == -888 } {
                set out "Serveur dans l'tat off"
             } elseif { $is != -999 } {
+               set bg 1
                set lcmd ""
                append lcmd [file join $astk::config($astk::inv(cmpl,$machexe,$user),rep_serv) "bin" as_run]
                append lcmd " --edit"
+               if { $action == "output_html" } {
+                  append lcmd " --result_to_output"
+                  set bg 0
+                  set type "output"
+               }
                append lcmd [ashare::get_glob_args]
                set displ $ashare::DISPLAY
                set argu "$num $nom $mode $type $displ"
-               set retour [ashare::rexec_cmd $astk::inv(cmpl,$machexe,$user) astk::config $lcmd $argu 1 out $asjob::fen_root]
+               set retour [ashare::rexec_cmd $astk::inv(cmpl,$machexe,$user) astk::config $lcmd $argu $bg out $asjob::fen_root]
+               if { $action == "output_html" } {
+                  set fres [file join $astk::tmpdir "$nom.$num.output"]
+                  set idout [open $fres "w"]
+                  puts $idout $out
+                  close $idout
+                  set retour [ashare::rexec_cmd -1 astk::config [file join $ashare::prefix "bin" "as_run"] "--convert_to_html --output=$fres.html $fres" 0 out $asjob::fen_root]
+                  ashare::file_open_url $fres.html
+               }
             } else {
                set out [ashare::mess ihm 360]
                ashare::mess erreur 47 $machexe $user
@@ -755,6 +770,7 @@ proc affiche_main { w } {
 proc asjob_popup { fensuiv m } {
    menu $m -tearoff 0 -bd 1
    $m add command -label "Editer output" -font $astk::ihm(font,labmenuB) -command "editJobSel $fensuiv.ftx1.lbx output"
+   #$m add command -label "Editer output.html BETA" -font $astk::ihm(font,labmenu) -command "editJobSel $fensuiv.ftx1.lbx output_html"
    $m add command -label "Editer error" -font $astk::ihm(font,labmenu)  -command "editJobSel $fensuiv.ftx1.lbx error"
    $m add command -label "Editer export" -font $astk::ihm(font,labmenu)  -command "editJobSel $fensuiv.ftx1.lbx export"
    $m add separator
