@@ -317,6 +317,7 @@ proc importer { type { append "non"}} {
       # as_run --get_export testcase
       append lcmd [file join $astk::config($srv,rep_serv) "bin" as_run]
       append lcmd " --get_export"
+      append lcmd " --vers=$astk::profil(version)"
       append lcmd " $tst"
       append lcmd [ashare::get_glob_args]
       # execution
@@ -616,7 +617,7 @@ proc check_exist_type { } {
             set ideb [expr $ilast + 1]
             set ilast $tabf($srv,nbfic)
             #
-            set cmd "/bin/sh -c \""
+            set cmd "$astk::cmd(shell_cmd) \""
             for {set nf $ideb} {$nf <= $ilast} {incr nf} {
                set vtab $tabf($srv,$nf)
                set var  [lindex $vtab 0]
@@ -696,8 +697,23 @@ proc import_astk_serv { fich append } {
             }
             memjeveux { }
             default {
-               ashare::log "<INFO> (import_astk_serv) Argument $mot inconnu (valeur=$val)"
-               set iret 2
+            # comportement par defaut
+               set trouv 0
+               # valeurs des arguments
+               set narg [expr [llength $astk::ihm(l_arg)] / 3]
+               for {set i 0} {$i < $narg} {incr i} {
+                  set arg  [lindex $astk::ihm(l_arg) [expr $i * 3]]
+                  if { $mot == $arg } {
+                     set astk::profil(option,$arg) 1
+                     set astk::profil(opt_val,$arg) $val
+                     set trouv 1
+                     break
+                  }
+               }
+               if { $trouv == 0 } {
+                  ashare::log "<INFO> Argument $mot inconnu (valeur=$val)"
+                  set iret 2
+               }
             }
          }
       } elseif { [regexp {^[ ]*P[ ]+([-a-z_A-Z0-9]*)[ ]+(.*[^ $])} $line bid mot val] == 1 } {
@@ -808,6 +824,8 @@ proc import_astk_serv { fich append } {
             special -
             xterm -
             mclient -
+            follow_output -
+            liste_test -
             uclient {
             # valeurs ignorees
             }
