@@ -36,7 +36,7 @@ proc lance_astk_serv { batch } {
 # - on regarde s'il y en a dj un
 # - on demande confirmation ventuellement
    if { $astk::profil(agla) == "oui" && $astk::profil(asrest) == "oui"  } {
-      set cmd "/bin/sh -c \"if test -d /aster/eda/"
+      set cmd "$astk::cmd(shell_cmd) \"if test -d /aster/eda/"
       append cmd "$astk::profil(version)/$astk::config($serv,login)"
       append cmd "; then echo EXIST ; else echo RAS ; fi\""
       change_status "[ashare::mess ihm 253]..."
@@ -144,7 +144,7 @@ proc retour_as_exec { nomjob out } {
 # indices ihm
    set serv $astk::inv(serv,$astk::profil(serveur))
    # decodage du retour
-   if { [regexp {JOBID[ ]*=[ ]*([0-9]+)} $out mat1 jobid] != 1 ||
+   if { [regexp {JOBID[ ]*=[ ]*([0-9a-zA-Z\._\-]+)} $out mat1 jobid] != 1 ||
         [regexp {QUEUE[ ]*=[ ]*([-a-z_A-Z0-9]+)} $out mat1 queue] != 1 } {
       set jret 3
    }
@@ -262,6 +262,8 @@ proc export_astk_serv { ftmp {tout_dist "non"} {verif_suppl "oui"}} {
          set repl "-$opt"
          if { $astk::profil(opt_val,$opt) != "" } {
             append repl " *$astk::profil(opt_val,$opt)"
+         }
+         if { $astk::profil(opt_val,$opt) != "" || $opt == "dbgjeveux" } {
             regsub -all -- "$repl" $tmp "" tmp
             puts $idexp "A $opt $astk::profil(opt_val,$opt)"
          }
