@@ -215,6 +215,7 @@ proc affiche_onglet { nom } {
    change_status [ashare::mess ihm 12]
 #
    raffr_agla_surch
+   raffr_args_fixe
 }
 
 # choix du sous-onglet ssong de l'onglet maitre nongl
@@ -346,32 +347,33 @@ proc affiche_arg { fen } {
 proc mod_argument { opt arg } {
    global getValue_val
 
-   set repl "-$opt"
-   if { $arg == "oui" && $astk::profil(option,$opt) == 0 } {
-      append repl " *$astk::profil(opt_val,$opt)"
-   }
-   regsub -all -- "$repl" $astk::profil(args_fixe) " " astk::profil(args_fixe)
-   set repl ""
-   if { $astk::profil(option,$opt) } {
-      append repl " -$opt"
-   }
    if { $arg == "oui" && $astk::profil(option,$opt) } {
       set last $astk::profil(opt_val,$opt)
       getValue_fen . 24 13 {} $last non_vide
       tkwait window .fen_getv
       if { $getValue_val != "_VIDE" } {
          set astk::profil(opt_val,$opt) $getValue_val
-         append repl " $getValue_val"
       } else {
-         set repl ""
          set astk::profil(option,$opt) 0
       }
    }
-   append astk::profil(args_fixe) "$repl"
-   regsub {^[ ]*} $astk::profil(args_fixe) "" astk::profil(args_fixe)
-   regsub {[ ]*$} $astk::profil(args_fixe) "" astk::profil(args_fixe)
+   raffr_args_fixe
 }
 
+# actualise la zone arguments fixes
+#################################################################
+proc raffr_args_fixe { } {
+    set astk::profil(args_fixe) ""
+    set narg [expr [llength $astk::ihm(l_arg)] / 3]
+    for {set i 0} {$i < $narg} {incr i} {
+      set arg  [lindex $astk::ihm(l_arg) [expr $i * 3]]
+      if { $astk::profil(option,$arg) == 1 } {
+         append astk::profil(args_fixe) "-$arg $astk::profil(opt_val,$arg) "
+      }
+    }
+}
+
+
 # modifie un paramtre
 #################################################################
 proc mod_param { m opt } {
