@@ -305,6 +305,7 @@ proc liste_icone { fenetre_icone fenetre_liste var } {
    button $fenetre_icone.detruire -image [image create photo -file $astk::icon(delete)] \
          -bd 0 -command "detr_act $fenetre_liste"
    pack $fenetre_icone.detruire -pady 3 -padx 3
+   bind $fenetre_icone.detruire <3> "bind_3_detruire %W %X %Y $var $fenetre_liste"
    
 # bouton editer
    if { $var != "surcharge" } {
@@ -314,14 +315,6 @@ proc liste_icone { fenetre_icone fenetre_liste var } {
       def_context $fenetre_icone.editer 194
    }
 
-# bouton exporter vers Salome
-   if { $ashare::origine == "from_salome" } {
-      button $fenetre_icone.salome_export -image [image create photo -file $astk::icon(salome)] \
-            -bd 0 -command "salome_export_act from_sel"
-      pack $fenetre_icone.salome_export -pady 3 -padx 3
-      def_context $fenetre_icone.salome_export 359
-   }
-
 # flches haut et bas
    if { $var == "etude" } {
       button $fenetre_icone.haut -image [image create photo -file $astk::icon(uparrow)] \
@@ -457,33 +450,7 @@ proc detr_act { fenetre_liste } {
    set i   $astk::sel(indice)
    if { $var != "" && $i != "" && $astk::profil($var,nbfic) > 0 } {
       modprof
-      set serv $astk::inv(serv,$astk::sel(servname))
-      incr astk::profil($var,nbfic) -1
-      for {set j $i} {$j < $astk::profil($var,nbfic)} {incr j 1} {
-         set j1 [expr $j + 1]
-         set astk::profil($var,fich,$j,nom)      $astk::profil($var,fich,$j1,nom)
-         set astk::profil($var,fich,$j,serv)     $astk::profil($var,fich,$j1,serv)
-         set astk::profil($var,fich,$j,type)     $astk::profil($var,fich,$j1,type)
-         set astk::profil($var,fich,$j,UL)       $astk::profil($var,fich,$j1,UL)
-         set astk::profil($var,fich,$j,donnee)   $astk::profil($var,fich,$j1,donnee)
-         set astk::profil($var,fich,$j,resultat) $astk::profil($var,fich,$j1,resultat)
-         set astk::profil($var,fich,$j,compress) $astk::profil($var,fich,$j1,compress)
-         set astk::profil($var,fich,$j,FR)       $astk::profil($var,fich,$j1,FR)
-      }
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),nom)
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),serv)
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),type)
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),UL)
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),donnee)
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),resultat)
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),compress)
-      unset astk::profil($var,fich,$astk::profil($var,nbfic),FR)
-      # dtruit les widgets associs  la dernire ligne
-      set lcols [colonnes_fich $var]
-      for {set iw 0} {$iw < [llength $lcols]} {incr iw} {
-         set wid [lindex $lcols $iw]
-         grid forget $fenetre_liste.lig($astk::profil($var,nbfic),$wid)
-      }
+      detruit_entree $var $fenetre_liste $i
    # interaction avec l'agla
       if { $var == "surcharge" } {
          raffr_agla_surch
@@ -496,6 +463,58 @@ proc detr_act { fenetre_liste } {
    }
 }
 
+# action clic droit sur le bouton dtruire
+#################################################################
+proc bind_3_detruire { w x y var fenetre_liste } {
+   #set var $astk::sel(liste)
+   ashare::log "#XXX DELETE_ALL $w, $x:$y $fenetre_liste / $var"
+   set iret [ tk_messageBox -message [ashare::mess ihm 390] \
+      -title [ashare::mess ihm 143] -type yesno -icon question ]
+   if { $iret == "yes" && $astk::profil($var,nbfic) > 0 } {
+      modprof
+      set nbfic $astk::profil($var,nbfic)
+      for {set i 0} {$i < $nbfic} {incr i} {
+         detruit_entree $var $fenetre_liste 0
+      }
+   # interaction avec l'agla
+      if { $var == "surcharge" } {
+         raffr_agla_surch
+      }
+   }
+}
+
+# dtruit l'entre de la liste numro i
+#################################################################
+proc detruit_entree { var fenetre_liste i} {
+   incr astk::profil($var,nbfic) -1
+   for {set j $i} {$j < $astk::profil($var,nbfic)} {incr j 1} {
+      set j1 [expr $j + 1]
+      set astk::profil($var,fich,$j,nom)      $astk::profil($var,fich,$j1,nom)
+      set astk::profil($var,fich,$j,serv)     $astk::profil($var,fich,$j1,serv)
+      set astk::profil($var,fich,$j,type)     $astk::profil($var,fich,$j1,type)
+      set astk::profil($var,fich,$j,UL)       $astk::profil($var,fich,$j1,UL)
+      set astk::profil($var,fich,$j,donnee)   $astk::profil($var,fich,$j1,donnee)
+      set astk::profil($var,fich,$j,resultat) $astk::profil($var,fich,$j1,resultat)
+      set astk::profil($var,fich,$j,compress) $astk::profil($var,fich,$j1,compress)
+      set astk::profil($var,fich,$j,FR)       $astk::profil($var,fich,$j1,FR)
+   }
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),nom)
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),serv)
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),type)
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),UL)
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),donnee)
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),resultat)
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),compress)
+   unset astk::profil($var,fich,$astk::profil($var,nbfic),FR)
+   # dtruit les widgets associs  la dernire ligne
+   set lcols [colonnes_fich $var]
+   for {set iw 0} {$iw < [llength $lcols]} {incr iw} {
+      set wid [lindex $lcols $iw]
+      grid forget $fenetre_liste.lig($astk::profil($var,nbfic),$wid)
+   }
+}
+
+
 # action o il faut simuler une reslection
 #################################################################
 proc reselect_act { fenetre_liste err } {
@@ -633,7 +652,7 @@ proc valeur_defaut { } {
    set def [get_valeur_defaut $astk::profil(nom_profil) "astk" $astk::profil($var,fich,$i,type) $astk::profil($var,fich,$i,UL)]
 # enlve le chemin de base
    if { $astk::profil(path_$var) != "" } {
-      regsub "^$astk::profil(path_$var)/" "$def" "./" def
+      set def "./[file tail $def]"
    }
    set astk::profil($var,fich,$i,serv) $astk::config($astk::profil(serv_profil),nom)
    set astk::profil($var,fich,$i,nom) $def
@@ -650,9 +669,6 @@ proc create_popup { m } {
    $m add command -label [ashare::mess ihm 179] -font $astk::ihm(font,labmenu)  -command {ashare::file_print_to}
    $m add separator
    $m add cascade -menu $m.opw -label [ashare::mess ihm 170] -font $astk::ihm(font,labmenu) -state disabled
-   if { $ashare::origine == "from_salome" } {
-      $m add command -label [ashare::mess ihm 358] -font $astk::ihm(font,labmenu)  -command {salome_export_act from_sel}
-   }
    $m add command -label [ashare::mess ihm 252] -font $astk::ihm(font,labmenu)  -command {valeur_defaut}
    $m add command -label [ashare::mess ihm 82] -font $astk::ihm(font,labmenu)   -command {ashare::file_terminal}
    $m add separator
