@@ -30,7 +30,7 @@ proc def_outils { } {
                            Grace    229 0 }
    set astk::ihm(outils_autocfg) { BSF Stanley MeshTool ConvBase }
    # attention pour la suite : tous les outils de outils_autocfg doivent tre dans outils
-   set astk::ihm(outils_cach) { astk EficasSalome }
+   set astk::ihm(outils_cach) { astk }
    # les outils cachs n'apparaissent nulle part, sauf pour lancer run_$outil
 }
 
@@ -94,10 +94,6 @@ proc run_tool { outil {numfich -1} } {
    set msg [ashare::mess ihm 165 $outil]
    change_status $msg
    update idletasks
-   # Pour Eficas, on ne lance pas celui configur par l'utilisateur si on vient de Salom
-   if { $outil == "Eficas" && $ashare::origine == "from_salome" } {
-      set outil EficasSalome
-   }
    if { [lsearch $astk::ihm(outils_autocfg) $outil] > -1 || [lsearch $astk::ihm(outils_cach) $outil] > -1} {
       set iret [run_$outil $numfich]
    } else {
@@ -153,7 +149,7 @@ proc run_tool { outil {numfich -1} } {
                      append ftmp $ftmp2
                      set ftmp [file join $astk::tmpdir $ftmp]
                      # recopie le fichier distant en local
-                     set macrcmd "/bin/sh -c \""
+                     set macrcmd "$astk::cmd(shell_cmd) \""
                      #set cmdcpy "rcp $astk::config($nsrv,login)@$astk::config($nsrv,nom_complet):$fich $ftmp"
                      set cmdcpy [ashare::rcp_cmd astk::config $nsrv $fich -1 $ftmp "commande"]
                      append macrcmd $cmdcpy
@@ -225,11 +221,6 @@ proc run_tool { outil {numfich -1} } {
    }
 }
 
-# Lancement d'eficas via RunEficasSalome si on vient de Salom
-#################################################################
-proc run_EficasSalome { {numfich -1} } {
-   event generate . <<RunEficasSalome>>
-}
 
 # Vrifie que les donnes ncessaires sont prsentes
 # puis appel le service "tool_stanley"
