@@ -24,8 +24,7 @@ namespace eval astk {
    variable lang
    variable check_quit
    variable recup
-   variable rcdir_base
-   variable rcdir_suff
+   variable rcdir_mod
    variable rcdir
    variable tmpdir
    variable local_server
@@ -37,6 +36,7 @@ namespace eval astk {
    variable fic_outils
    variable fic_print
    variable modprof
+   # command line (ps, shell_cmd)
    variable cmd
    variable platform
 
@@ -58,8 +58,8 @@ namespace eval astk {
 }
 
 # valeurs par dfaut
-set astk::rcdir_base ".astkrc"
-set astk::rcdir_suff ""
+set astk::rcdir ".astkrc"
+set astk::rcdir_mod 0
 
 # pr-traitement des arguments
 # pour le moment uniquement pour dfinir astk::rcdir
@@ -71,9 +71,8 @@ proc pre_traite_argv { } {
          --rcdir {
             if { $i < [ expr $argc - 1 ] } {
                incr i
-               set ext [lindex $argv $i]
-               set astk::rcdir_base ".astkrc_$ext"
-               set astk::rcdir_suff $ext
+               set astk::rcdir [lindex $argv $i]
+               set astk::rcdir_mod 1
             }
          }
       }
@@ -132,6 +131,11 @@ proc init_gene { root } {
          ashare::log "<ERREUR 000> Unsupported platform : $astk::platform"
          ashare::my_exit 4
    }
+   if { $astk::platform == "unix" } {
+       set astk::cmd(shell_cmd) "bash -c"
+   } else {
+       set astk::cmd(shell_cmd) "cmd.exe"
+   }
 
 # $DISPLAY
    init_display
@@ -156,7 +160,7 @@ proc init_gene { root } {
    set astk::config(-1,etat) "on"
 
 # chemin des ressources
-   set astk::rcdir [file join $astk::config(-1,home) $astk::rcdir_base]
+   set astk::rcdir [file join $astk::config(-1,home) $astk::rcdir]
 
 # rpertoire temporaire
    set astk::tmpdir "/tmp/astk_$astk::config(-1,login)"
