@@ -743,8 +743,7 @@ proc tkgetdir::ShowDir {curdir} {
       if { [string index $rdir end] != "/" } { append rdir "/" }
       if { [string index $curdir end] != "/" } { append curdir "/" }
       set curdirls $curdir
-#      set cmd "/bin/sh -c \"if test -d $curdirls ; then echo $curdirls ; /bin/ls $tkgetdir::ls_args $curdirls ; else echo $rdir ; /bin/ls $tkgetdir::ls_args $rdir ; fi\""
-      set cmd "/bin/sh -c \"if test -d '$curdirls' ; then echo '$curdirls' ; /bin/ls $tkgetdir::ls_args '$curdirls' ; else echo '$rdir' ; /bin/ls $tkgetdir::ls_args '$rdir' ; fi\""
+      set cmd "$astk::cmd(shell_cmd) \"if test -d '$curdirls' ; then echo '$curdirls' ; /bin/ls $tkgetdir::ls_args '$curdirls' ; else echo '$rdir' ; /bin/ls $tkgetdir::ls_args '$rdir' ; fi\""
       set t0 [clock clicks -milliseconds]
       set iret [ ashare::rexec_cmd $tkgetdir::icurmach tkgetdir::config $cmd "" 0 retour_ls $tkgetdir::dirsel]
       ashare::pointeur off
@@ -895,8 +894,7 @@ proc tkgetdir::DownDir { } {
       set tkgetdir::status [ashare::mess ihm 231]
       update idletasks
       set areDirs 0
-#      set cmd "/bin/sh -c \"/bin/ls $tkgetdir::ls_args $newdir/\""
-      set cmd "/bin/sh -c \"/bin/ls $tkgetdir::ls_args '$newdir/'\""
+      set cmd "$astk::cmd(shell_cmd) \"/bin/ls $tkgetdir::ls_args '$newdir/'\""
       set t0 [clock clicks -milliseconds]
       set iret [ ashare::rexec_cmd $tkgetdir::icurmach tkgetdir::config $cmd "" 0 retour_ls $tkgetdir::dirsel]
       set t1 [clock clicks -milliseconds]
@@ -1744,7 +1742,7 @@ proc tkgetdir::file_paste { } {
       }
    # doit-on effacer la source ?
       if { $tkgetdir::sel(delete) } {
-         set cmd "/bin/sh -c \""
+         set cmd "$astk::cmd(shell_cmd) \""
          append cmd [ashare::rcp_cmd tkgetdir::config $srv_in $nam_in $srv_out $dir_out commande]
          append cmd " ; /bin/rm -rf $nam_in"
          append cmd "\""
@@ -1875,13 +1873,13 @@ proc tkgetdir::OpenTerm { } {
    set dir [$tkgetdir::dirsel.f1.dir cget -text]
    set xt $tkgetdir::config($srv,xterm)
    if { $xt != "" } {
-      set cmd "/bin/sh -c \"cd $dir ; "
+      set cmd "$astk::cmd(shell_cmd) \"cd $dir ; "
       if { [regexp -- {@D} $xt] == 0 } {
          append xt " -display @D"
       }
       append cmd $xt
       append cmd "\""
-	   ashare::rexec_cmd $srv tkgetdir::config $cmd "" 1 out
+       ashare::rexec_cmd $srv tkgetdir::config $cmd "" 1 out
    } else {
       set msg [ashare::mess erreur 15 [ashare::mess ihm 82] $tkgetdir::config($srv,nom)]
       tk_messageBox -message $msg -type ok -icon info -parent $tkgetdir::dirsel
@@ -1923,12 +1921,12 @@ proc tkgetdir::ExecCmde { parent } {
    set ini "/bin/sh"
    catch {set ini $ExecCmde_shell}
    set ExecCmde_shell $ini
-	radiobutton $fen.sh.sh   -font $astk::ihm(font,lab) -text /bin/sh   -value /bin/sh   -variable ExecCmde_shell
-	radiobutton $fen.sh.csh  -font $astk::ihm(font,lab) -text /bin/csh  -value /bin/csh  -variable ExecCmde_shell
-	radiobutton $fen.sh.ksh  -font $astk::ihm(font,lab) -text /bin/ksh  -value /bin/ksh  -variable ExecCmde_shell
-	radiobutton $fen.sh.bash -font $astk::ihm(font,lab) -text /bin/bash -value /bin/bash -variable ExecCmde_shell
-	radiobutton $fen.sh.tcsh -font $astk::ihm(font,lab) -text /bin/tcsh -value /bin/tcsh -variable ExecCmde_shell
-	radiobutton $fen.sh.zsh  -font $astk::ihm(font,lab) -text /bin/zsh  -value /bin/zsh  -variable ExecCmde_shell
+    radiobutton $fen.sh.sh   -font $astk::ihm(font,lab) -text /bin/sh   -value /bin/sh   -variable ExecCmde_shell
+    radiobutton $fen.sh.csh  -font $astk::ihm(font,lab) -text /bin/csh  -value /bin/csh  -variable ExecCmde_shell
+    radiobutton $fen.sh.ksh  -font $astk::ihm(font,lab) -text /bin/ksh  -value /bin/ksh  -variable ExecCmde_shell
+    radiobutton $fen.sh.bash -font $astk::ihm(font,lab) -text /bin/bash -value /bin/bash -variable ExecCmde_shell
+    radiobutton $fen.sh.tcsh -font $astk::ihm(font,lab) -text /bin/tcsh -value /bin/tcsh -variable ExecCmde_shell
+    radiobutton $fen.sh.zsh  -font $astk::ihm(font,lab) -text /bin/zsh  -value /bin/zsh  -variable ExecCmde_shell
 
    pack $fen.txt -fill x -expand 1
    pack $fen.txt.lbl -padx 10 -pady 5 -side left -anchor w
@@ -1955,7 +1953,7 @@ proc tkgetdir::ExecCmde_action { shell cmde } {
       set cmd "$shell -c \""
       append cmd $cmde
       append cmd "\""
-	   ashare::rexec_cmd $srv tkgetdir::config $cmd "" 0 out $tkgetdir::dirsel
+       ashare::rexec_cmd $srv tkgetdir::config $cmd "" 0 out $tkgetdir::dirsel
    # output
       set num [clock seconds]
       set fen .fen_output_$num
