@@ -2,6 +2,7 @@
 
 import sys
 import os
+import os.path as osp
 import re
 from glob import glob
 from distutils           import log, sysconfig
@@ -18,26 +19,34 @@ from configuration.util  import (read_rcfile, replace_rcfile, print_diff, backup
 # at build step (not sure) and "data_files" are not in 'build' directory.
 
 # regular expression for variables of this form : ?VVVVVV?
-regexp = re.compile('\?{1}([^\'\"|]+?)\?{1}', re.MULTILINE)
+VAR_REGEXP = re.compile('\?{1}([^\'\"\n|]+?)\?{1}', re.MULTILINE)
 # must not be changed
-exceptions = ('vers : VVV', )
+EXCEPTIONS = ('vers : VVV', )
 
 
-def finalize(prefix, parameters, version):
+def finalize(rootdir, prefix, parameters, version, **options):
    """Finalize the installation :
    - configure files using 'parameters' dict,
    - add some DeprecatingWarning
    """
    log.info("finalizing installation in %s...", prefix)
    # fill the variables of the form ?VVV?
-   files = get_files_to_change(prefix)
+   files = get_files_to_change(rootdir, prefix)
    for filename in files:
       log.info("configuring %s...", filename)
       change_file(filename, parameters)
    # already done by install_scripts but just changed...
-   chmod_scripts(glob(os.path.join(prefix, 'bin', '*')))
-   for alias in ('show', 'get', 'getop'):
-      os.symlink('as_run', os.path.join(prefix, 'bin', alias))
+   chmod_scripts(glob(os.path.join(rootdir + prefix, 'bin', '*')))
+   for dest, l_alias in [('as_run', ('codeaster', 'show', 'get', 'getop')),
+                         ('astk',   ('codeaster-gui',))]:
+      for alias in l_alias:
+          alias = os.path.join(rootdir + prefix, 'bin', alias)
+          try:
+             if os.path.exists(alias):
+                os.remove(alias)
+             os.symlink(dest, alias)
+          except (IOError, OSError):
+             pass
 
    files = set(files)
    # fill configuration files (restore fields of the form 'parameter : value')
@@ -52,11 +61,24 @@ def finalize(prefix, parameters, version):
          if os.path.exists(previous):
             copy_file(previous, backup_name(new, '.orig'))
 ##            log.info(print_diff(backup_name(new, '.orig'), new))  # python-Bugs-1541642
+      # copy previously existing files
+      newdir = osp.join(prefix2etc(prefix), 'codeaster')
+      # do not overwrite changed files
+      ignore_list = files.copy()
+      ignore_list.update(parameters['server_config_files'].values())
+      # exceptions
+      ignore_list.add(osp.join(parameters['server_confdir'], 'aster_profile.sh'))
+      for old_file in os.listdir(parameters['server_confdir']):
+         new = osp.join(newdir, old_file)
+         if new in ignore_list or osp.join(parameters['server_confdir'], old_file) in ignore_list:
+            continue
+         if not osp.exists(new):
+            copy_file(osp.join(parameters['server_confdir'], old_file), new)
 
    # restore client configuration file
    if parameters['client_confdir'] != '':
       for new, previous in parameters['client_config_files'].items():
-         new = os.path.join(prefix2etc(prefix), 'codeaster', new)
+         new = osp.join(prefix2etc(prefix), 'codeaster', new)
          if os.path.exists(previous):
             move_file(new, backup_name(new, '.new'))
             copy_file(previous, new)
@@ -66,8 +88,9 @@ def finalize(prefix, parameters, version):
       migrate(prefix, parameters, version)
 
    # keep deprecation warning up to 1.9.0
-   if version is None or less_than_version(version, '1.9.0'):
-      backward_compatibility(prefix)
+   if not options.get("nodeprecation") and \
+      (version is None or less_than_version(version, '1.9.0')):
+      backward_compatibility(rootdir + prefix)
 
    # check for residual variables
    files = list(files)
@@ -75,7 +98,7 @@ def finalize(prefix, parameters, version):
    for filename in files:
       check_unchanged_residual(filename)
 
-   remove_tree(os.path.join(prefix, '.as_run_configuration'))
+   remove_tree(os.path.join(rootdir + prefix, '.as_run_configuration'))
    log.info("post-installation completed")
 
 
@@ -114,7 +137,7 @@ def replace_from_expr(filename, param, dict_expr):
 
 
 def change_file(filename, dict_trans, backup_extension=''):
-   """Change the variables in 'filename' (according to regexp)"""
+   """Change the variables in 'filename' (according to VAR_REGEXP)"""
    def func_repl(matchobj):
       var = matchobj.group(1)
       val = dict_trans.get(var, '?' + var + '?')
@@ -127,7 +150,7 @@ def change_file(filename, dict_trans, backup_extension=''):
    content = open(filename, 'r').read()
    if backup_extension:
       open(filename + backup_extension, 'w').write(content)
-   changed = regexp.sub(func_repl, content)
+   changed = VAR_REGEXP.sub(func_repl, content)
    open(filename, 'w').write(changed)
 
 
@@ -135,8 +158,8 @@ def check_unchanged_residual(filename):
    """Check for undefined variables.
    """
    content = open(filename, 'r').read()
-   unchanged = set(regexp.findall(content))
-   unchanged.difference_update(exceptions)
+   unchanged = set(VAR_REGEXP.findall(content))
+   unchanged.difference_update(EXCEPTIONS)
    if len(unchanged) > 0:
       unchanged = list(unchanged)
       unchanged.sort()
@@ -144,16 +167,21 @@ def check_unchanged_residual(filename):
       log.info('  ' + ', '.join(unchanged))
 
 
-def get_files_to_change(prefix):
+def get_files_to_change(rootdir, prefix):
    """Build the list of files to change."""
+   log.info("building list of the files to change (from %s)...", prefix)
+   log.debug("... searching from %s", rootdir + prefix)
+   log.debug("... searching from %s", rootdir + prefix2etc(prefix))
    # glob ignores files beginning with a dot (.mysql_connect)
    files = []
-   files.extend(glob(os.path.join(prefix, 'bin', '*')))
-   files.extend(glob(os.path.join(prefix2etc(prefix), 'codeaster', '*')))
-   files.extend(glob(os.path.join(prefix2etc(prefix), 'codeaster', 'astkrc', '*')))
-   files.extend(glob(os.path.join(prefix, 'share', 'codeaster', 'asrun', 'data', '*')))
-   files.extend([os.path.join(sysconfig.get_python_lib(prefix=prefix), 'asrun', 'installation.py')])
+   files.extend(glob(os.path.join(rootdir +prefix, 'bin', '*')))
+   files.extend(glob(os.path.join(rootdir + prefix2etc(prefix), 'codeaster', '*')))
+   files.extend(glob(os.path.join(rootdir + prefix2etc(prefix), 'codeaster', 'astkrc', '*')))
+   files.extend(glob(os.path.join(rootdir + prefix, 'share', 'codeaster', 'asrun', 'data', '*')))
+   files.extend([os.path.join(sysconfig.get_python_lib(prefix=rootdir+prefix), 'asrun', 'installation.py')])
    files = [f for f in files if os.path.isfile(f)]
+   log.info(" %8d files found", len(files))
+   log.debug("%s", repr(files))
    return files
 
 
